@@ -4,36 +4,70 @@ Library
    Based on the Linux screenreader BRLTTY, copyright (C) 1999-2006 by
    The BRLTTY Team
 
-   Copyright (C) 2004, 2005, 2006
-   ViewPlus Technologies, Inc. www.viewplus.com
-   and
+   Copyright (C) 2004, 2005, 2006, 2009
+   ViewPlus Technologies, Inc. www.viewplus.com and
    JJB Software, Inc. www.jjb-software.com
-   All rights reserved
 
-   This file is free software; you can redistribute it and/or modify it
-   under the terms of the Lesser or Library GNU General Public License 
-   as published by the
-   Free Software Foundation; either version 3, or (at your option) any
-   later version.
-
-   This file is distributed in the hope that it will be useful, but
-   WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
-   Library GNU General Public License for more details.
-
-   You should have received a copy of the Library GNU General Public 
-   License along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+   
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
    Maintained by John J. Boyer john.boyer@jjb-software.com
    */
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include "liblouis.h"
 #include "louis.h"
+#include <getopt.h>
+#include "progname.h"
+#include "version-etc.h"
+
+static const struct option longopts[] =
+{
+  { "help", no_argument, NULL, 'h' },
+  { "version", no_argument, NULL, 'v' },
+  { NULL, 0, NULL, 0 }
+};
+
+const char version_etc_copyright[] =
+  "Copyright %s %d ViewPlus Technologies, Inc. and JJB Software, Inc.";
+
+#define AUTHORS "John J. Boyer"
+
+static void
+print_help (void)
+{
+  printf ("\
+Usage: %s [OPTION]\n", program_name);
+  
+  fputs ("\
+This program tests every capability of the liblouis library. It is\n\
+completely interactive. \n\n", stdout);
+
+  fputs ("\
+  -h, --help          display this help and exit\n\
+  -v, --version       display version information and exit\n", stdout);
+
+  printf ("\n");
+  printf ("\
+Report bugs to <%s>.\n", PACKAGE_BUGREPORT);
+}
+
 #define BUFSIZE 256
 
 static char inputBuffer[BUFSIZE];
@@ -220,7 +254,7 @@ getCommands (void)
 }
 
 int
-main ()
+main (int argc, char **argv)
 {
   widechar inbuf[BUFSIZE];
   widechar transbuf[BUFSIZE];
@@ -233,6 +267,39 @@ main ()
   int cursorPos;
   int realInlen = 0;
   int k;
+  int optc;
+
+  set_program_name (argv[0]);
+
+  while ((optc = getopt_long (argc, argv, "hv", longopts, NULL)) != -1)
+    switch (optc)
+      {
+      /* --help and --version exit immediately, per GNU coding standards.  */
+      case 'v':
+        version_etc (stdout, program_name, PACKAGE_NAME, VERSION, AUTHORS, (char *) NULL);
+        exit (EXIT_SUCCESS);
+        break;
+      case 'h':
+        print_help ();
+        exit (EXIT_SUCCESS);
+        break;
+      default:
+	fprintf (stderr, "Try `%s --help' for more information.\n",
+		 program_name);
+	exit (EXIT_FAILURE);
+        break;
+      }
+
+  if (optind < argc)
+    {
+      /* Print error message and exit.  */
+      fprintf (stderr, "%s: extra operand: %s\n",
+	       program_name, argv[optind]);
+      fprintf (stderr, "Try `%s --help' for more information.\n",
+               program_name);
+      exit (EXIT_FAILURE);
+    }
+
   validTable = NULL;
   enteredCursorPos = -1;
   mode = 0;
